@@ -2,6 +2,10 @@ class DataSDKError(Exception):
     """Base exception class."""
 
 
+class DataFrameParsingError(DataSDKError):
+    """Unable to parse DataFrame"""
+
+
 class UnknownMediaTypeError(DataSDKError):
     """Unknown Media Type"""
 
